# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassifiedRegion2D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import BoundingBox_pb2 as rst_dot_geometry_dot_BoundingBox__pb2
from rst.classification import ClassificationResult_pb2 as rst_dot_classification_dot_ClassificationResult__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassifiedRegion2D.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n+rst/classification/ClassifiedRegion2D.proto\x12\x12rst.classification\x1a\x1erst/geometry/BoundingBox.proto\x1a-rst/classification/ClassificationResult.proto\"y\n\x12\x43lassifiedRegion2D\x12)\n\x06region\x18\x01 \x01(\x0b\x32\x19.rst.geometry.BoundingBox\x12\x38\n\x06result\x18\x02 \x01(\x0b\x32(.rst.classification.ClassificationResultB\x18\x42\x16\x43lassifiedRegion2DType')
  ,
  dependencies=[rst_dot_geometry_dot_BoundingBox__pb2.DESCRIPTOR,rst_dot_classification_dot_ClassificationResult__pb2.DESCRIPTOR,])




_CLASSIFIEDREGION2D = _descriptor.Descriptor(
  name='ClassifiedRegion2D',
  full_name='rst.classification.ClassifiedRegion2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.classification.ClassifiedRegion2D.region', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='rst.classification.ClassifiedRegion2D.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=267,
)

_CLASSIFIEDREGION2D.fields_by_name['region'].message_type = rst_dot_geometry_dot_BoundingBox__pb2._BOUNDINGBOX
_CLASSIFIEDREGION2D.fields_by_name['result'].message_type = rst_dot_classification_dot_ClassificationResult__pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassifiedRegion2D'] = _CLASSIFIEDREGION2D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassifiedRegion2D = _reflection.GeneratedProtocolMessageType('ClassifiedRegion2D', (_message.Message,), dict(
  DESCRIPTOR = _CLASSIFIEDREGION2D,
  __module__ = 'rst.classification.ClassifiedRegion2D_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassifiedRegion2D)
  ))
_sym_db.RegisterMessage(ClassifiedRegion2D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026ClassifiedRegion2DType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/WrenchCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dynamics import Wrench_pb2 as rst_dot_dynamics_dot_Wrench__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/WrenchCollection.proto',
  package='rst.dynamics',
  syntax='proto2',
  serialized_pb=_b('\n#rst/dynamics/WrenchCollection.proto\x12\x0crst.dynamics\x1a\x19rst/dynamics/Wrench.proto\"9\n\x10WrenchCollection\x12%\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x14.rst.dynamics.WrenchB\x16\x42\x14WrenchCollectionType')
  ,
  dependencies=[rst_dot_dynamics_dot_Wrench__pb2.DESCRIPTOR,])




_WRENCHCOLLECTION = _descriptor.Descriptor(
  name='WrenchCollection',
  full_name='rst.dynamics.WrenchCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.dynamics.WrenchCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=137,
)

_WRENCHCOLLECTION.fields_by_name['element'].message_type = rst_dot_dynamics_dot_Wrench__pb2._WRENCH
DESCRIPTOR.message_types_by_name['WrenchCollection'] = _WRENCHCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WrenchCollection = _reflection.GeneratedProtocolMessageType('WrenchCollection', (_message.Message,), dict(
  DESCRIPTOR = _WRENCHCOLLECTION,
  __module__ = 'rst.dynamics.WrenchCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.dynamics.WrenchCollection)
  ))
_sym_db.RegisterMessage(WrenchCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024WrenchCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPolygonalPatches3D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackedPolygonalPatch3D_pb2 as rst_dot_tracking_dot_TrackedPolygonalPatch3D__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPolygonalPatches3D.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n,rst/tracking/TrackedPolygonalPatches3D.proto\x12\x0crst.tracking\x1a*rst/tracking/TrackedPolygonalPatch3D.proto\"Q\n\x19TrackedPolygonalPatches3D\x12\x34\n\x05patch\x18\x01 \x03(\x0b\x32%.rst.tracking.TrackedPolygonalPatch3DB\x1f\x42\x1dTrackedPolygonalPatches3DType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackedPolygonalPatch3D__pb2.DESCRIPTOR,])




_TRACKEDPOLYGONALPATCHES3D = _descriptor.Descriptor(
  name='TrackedPolygonalPatches3D',
  full_name='rst.tracking.TrackedPolygonalPatches3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patch', full_name='rst.tracking.TrackedPolygonalPatches3D.patch', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=187,
)

_TRACKEDPOLYGONALPATCHES3D.fields_by_name['patch'].message_type = rst_dot_tracking_dot_TrackedPolygonalPatch3D__pb2._TRACKEDPOLYGONALPATCH3D
DESCRIPTOR.message_types_by_name['TrackedPolygonalPatches3D'] = _TRACKEDPOLYGONALPATCHES3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPolygonalPatches3D = _reflection.GeneratedProtocolMessageType('TrackedPolygonalPatches3D', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOLYGONALPATCHES3D,
  __module__ = 'rst.tracking.TrackedPolygonalPatches3D_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPolygonalPatches3D)
  ))
_sym_db.RegisterMessage(TrackedPolygonalPatches3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035TrackedPolygonalPatches3DType'))
# @@protoc_insertion_point(module_scope)
